@@ -55,6 +55,9 @@ iso_time (time_t *);
 char *
 iso_time_tz (time_t *, const char *, const char **);
 
+char *
+iso_if_time (time_t epoch_time);
+
 /**
  * @brief Lockfile.
  */
@@ -85,6 +88,12 @@ lockfile_locked (const gchar *);
 int
 is_uuid (const char *);
 
+gchar *
+strescape_check_utf8 (const char *, const char *);
+
+gchar *
+strescape_without_utf8 (const char *, const char *);
+
 int
 parse_xml_file (const gchar *, entity_t *);
 
@@ -97,4 +106,13 @@ setup_signal_handler_info (int, void (*) (int, siginfo_t *, void *), int);
 int
 fork_with_handlers ();
 
+void
+wait_for_pid (pid_t, const char *);
+
+guint64
+phys_mem_available ();
+
+guint64
+phys_mem_total ();
+
 #endif /* not _GVMD_UTILS_H */
